==> glexec-0.8.10.tar.gz: glexec-0.8.10/src/glexec_conf.h <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2006-2010.
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Authors:
 * 2009-
 *      Oscar Koeroo <okoeroo@nikhef.nl>
 *      Mischa Sall\'e <msalle@nikhef.nl>
 *      NIKHEF Amsterdam, the Netherlands
 *
 *  2006-2009
 *      Gerben Venekamp <venekamp@nikhef.nl>
 *      NIKHEF Amsterdam, the Netherlands
 *
 */

/*!
 *  \file glexec_conf.h
 *
 *  Provides methods to read the configuration file and retrieve key/value
 *  pairs.
 */

#ifndef _GLEXEC_CONF_H
#define _GLEXEC_CONF_H

/* For GLEXEC_ERROR */
#include "glexec_exit.h"

/* For uid_t/gid_t */
#include <sys/types.h>

/*************************************************************************/
/* FUNCTION DECLARATIONS                                                 */
/*************************************************************************/

/*!
 * Opens given config_file using given unprivileged uid/gid. When
 * unpriv_gid==-1, it is ignored. See cgul_read_config() for details.
 * \param config_file filename
 * \param unpriv_uid unprivileged uid
 * \param unpriv_gid unprivileged gid
 * \return error when reading failed.
 */
GLEXEC_ERROR glexec_conf_read_config(const char *config_file,
				     uid_t unpriv_uid, int unpriv_gid);

/*!
 * Looks up value for given key.
 * \param key
 * \return value or NULL when unset.
 */
const char *glexec_conf_value(const char *key);

/*!
 * Looks up value for given key
 * \param key
 * \param def_value default value to use when unset
 * \return value or def_value.
 */
const char *glexec_conf_value_default(const char *key, const char *def_value);

/*!
 * Frees memory allocated for the configuration.
 */
void glexec_conf_close(void);

#endif

==> glexec_0.9.8.orig.tar.gz: glexec-0.9.8/src/glexec_conf.h <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2006-2010.
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Authors:
 * 2009-
 *      Oscar Koeroo <okoeroo@nikhef.nl>
 *      Mischa Sall\'e <msalle@nikhef.nl>
 *      NIKHEF Amsterdam, the Netherlands
 *
 *  2006-2009
 *      Gerben Venekamp <venekamp@nikhef.nl>
 *      NIKHEF Amsterdam, the Netherlands
 *
 */

/*!
 *  \file glexec_conf.h
 *
 *  Provides functions to read the configuration file and retrieve key/value
 *  pairs.
 */

#ifndef _GLEXEC_CONF_H
#define _GLEXEC_CONF_H

/* For GLEXEC_ERROR */
#include "glexec_exit.h"

/* Max number of entries in config list */
#ifndef GLEXEC_CONF_ELEM_MAX
#define GLEXEC_CONF_ELEM_MAX	((size_t)200U)
#endif

/* For uid_t/gid_t */
#include <sys/types.h>

/*************************************************************************/
/* FUNCTION DECLARATIONS                                                 */
/*************************************************************************/

/*!
 * Opens given config_file using given unprivileged uid/gid.
 * See cgul_read_config() for details.
 * \param config_file filename
 * \param unpriv_uid unprivileged uid
 * \param unpriv_gid unprivileged gid
 * \return error when reading failed.
 */
GLEXEC_ERROR glexec_conf_read_config(const char *config_file,
				     uid_t unpriv_uid, gid_t unpriv_gid);

/*!
 * Looks up value for given key.
 * \param key
 * \return value or NULL when unset.
 */
char *glexec_conf_value(const char *key);

/*!
 * Looks up value for given key
 * \param key
 * \param def_value default value to use when unset
 * \return value or def_value.
 */
const char *glexec_conf_value_default(const char *key, const char *def_value);

/*!
 * Looks up value for given key which may be yes/true or no/false. When value is
 * different an error is logged and the default is returned.
 * \param key
 * \param def_value: return value when no value is given
 * \return 1 when yes/true, 0 when no/false
 */
int glexec_conf_boolean(const char *key, int def_value);

/*!
 * Frees memory allocated for the configuration.
 */
void glexec_conf_close(void);

#endif
